##
##  reposurgeon.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2021 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         reposurgeon
Summary:      VCS Repository Utility
URL:          http://www.catb.org/~esr/reposurgeon/
Vendor:       Eric S. Raymond
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        SCM
License:      BSD
Version:      4.30
Release:      20211015

#   list of sources
Source0:      http://www.catb.org/~esr/reposurgeon/reposurgeon-%{version}.tar.xz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  ncurses
PreReq:       ncurses

%description
    Reposurgeon enables risky operations that version-control systems
    don't want to let you do, such as editing past comments and metadata
    and removing commits. It works with any version control system that
    can export and import git fast-import streams, including git and hg
    and bzr.

%track
    prog reposurgeon = {
        version   = %{version}
        url       = http://www.catb.org/~esr/reposurgeon/
        regex     = reposurgeon-(__VER__)\.tar\.xz
    }

%prep
    %setup -q

%build
    export GOPATH=`pwd`
    mkdir -p $GOPATH/.src/gitlab.com/esr/reposurgeon
    mv * $GOPATH/.src/gitlab.com/esr/reposurgeon/
    mv $GOPATH/.src $GOPATH/src
    (   cd $GOPATH/src/gitlab.com/esr/reposurgeon
        %{l_make} %{l_mflags} build
    ) || exit $?
    %{l_shtool} subst \
        -e 's;/etc/terminfo;%{l_prefix}/share/ncurses/terminfo;g' \
        pkg/mod/github.com/xo/terminfo*/load.go
    (   cd $GOPATH/src/gitlab.com/esr/reposurgeon
        %{l_make} %{l_mflags} build
    ) || exit $?

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    (   cd src/gitlab.com/esr/reposurgeon
        %{l_shtool} install -c -m 755 \
            -e 's;#!/bin/bash;#!%{l_bash};' \
            repobench \
            $RPM_BUILD_ROOT%{l_prefix}/bin/
        %{l_shtool} install -c -m 755 \
            repocutter repomapper reposurgeon repotool \
            $RPM_BUILD_ROOT%{l_prefix}/bin/
        %{l_shtool} install -c -m 644 \
            *.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    ) || exit $?
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

